@@ -2,7 +2,7 @@
 
 __author__ = 'Aron Culotta'
 __email__ = 'aronwc@gmail.com'
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 import csv
 import errno
@@ -15,14 +15,17 @@ import traceback
 
 def extract_metadata(text, result):
     """
-    >>> extract_metadata('@name=a0/foo.py...', {})['file_to_test']
-    'a0/foo.py'
+    >>> extract_metadata('@name=a0/foo.py', {})['files_to_test']
+    ['a0/foo.py']
+    >>> extract_metadata('@name=a0/foo.py,a0/bar.py', {})['files_to_test']
+    ['a0/foo.py', 'a0/bar.py']
     >>> extract_metadata('@possible_points=12.4', {})['possible_points']
     12.4
     """
-    match = re.search(r'\@name\s*=\s*(.+.py)', text)
+    match = re.search(r'\@name\s*=\s*(.+)', text)
     if match:
-        result['file_to_test'] = match.group(1)
+        filenames = match.group(1)
+        result['files_to_test'] = re.split('\s*,\s*', filenames)
     match = re.search(r'\@possible_points\s*=\s*([0-9\.]+)', text)
     if match:
         result['possible_points'] = float(match.group(1))
@@ -82,6 +85,14 @@ def clone_repo(student, path):
         print(e)
         return False
 
+def pull_repo(local_repo):
+    try:
+        repo = git.Repo(local_repo)
+        repo.remotes[0].pull()
+    except git.exc.GitCommandError as e:
+        print(e)
+        return False
+
 
 def clone_repos(students, path):
     """ Clone all student repos. """
